@@ -15,11 +15,12 @@
 #  limitations under the License.
 
 # from xml.etree import ElementTree as ET
+
 from lxml import etree as ET
 from .palette import (TextState, BaseColorMapping,
                      ConsoleCodeMapping, LightColorMapping, ConsoleColor256,
                      ConsoleCodesInfo, SpanPalette, XmlFormat)
-
+import re
 
 class BaseOutput():
     """
@@ -559,6 +560,8 @@ class XmlOutput(SaveAttrOutput):
             tail = ET.SubElement(tail, Tags.UNDERLINE)
         if curstate.bold:
             tail = ET.SubElement(tail, Tags.BOLD)
+        #TODO debug here
+        text = re.sub('[^\u0020-\uD7FF\u0009\u000A\u000D\uE000-\uFFFD\U00010000-\U0010FFFF]+', '', text)
         tail.text = text
         # return root[0]
         return root
