@@ -23,7 +23,7 @@ import datetime
 import functools
 import bz2
 
-from ..cl_xml import ET
+from ..cl_xml import ET, str_to_xml_doc
 import pexpect
 from ..configparser import ConfigParser
 
@@ -689,7 +689,7 @@ class PackageInformation:
             output = pexpect.spawn(self.eix_cmd, ["--xml", pkg_list],
                                    timeout=60).read()
         except pexpect.TIMEOUT:
-            output = ""
+            output = b""
         re_cut = re.compile(b"^.*?(?=<\?xml version)", re.S)
         with ignore(ET.ParseError):
             xml = ET.fromstring(re_cut.sub(b'', output))
@@ -891,7 +891,7 @@ class EixParser():
     """
     def parseXml(self, buffer):
         try:
-            eix_xml = ET.fromstring(buffer)
+            eix_xml = str_to_xml_doc(buffer)
             return self.get_categories(eix_xml)
         except ET.ParseError:
             return iter(())
@@ -1427,7 +1427,7 @@ class InstalledPackageInfo():
         env_path = path.join(self._pkg_path, 'environment.bz2')
         if path.exists(env_path):
             with bz2.BZ2File(env_path, 'r') as f:
-                for r in self.re_depend.finditer(f.read()):
+                for r in self.re_depend.finditer(f.read().decode("UTF-8")):
                     key, value = r.groups()
                     value = self.re_multispace.sub(" ", value)
                     info[key] = value.strip()
