@@ -14,24 +14,23 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
 import sys
 import os
 from os import path
 import re
 import platform
-from calculate.lib.datavars import (Variable, SimpleDataVars, ReadonlyVariable,
+from ..datavars import (Variable, SimpleDataVars, ReadonlyVariable,
                                     VariableError, VariableInterface)
 
-from calculate.lib.utils.portage import (isPkgInstalled, searchProfile,
+from ..utils.portage import (isPkgInstalled, searchProfile,
                                          RepositorySubstituting, RepositoryPath)
-from calculate.lib.utils.files import readFile, pathJoin
-from calculate.lib.configparser import ConfigParser
-from calculate.lib.utils.tools import unique, drop_slash
+from ..utils.files import readFile, pathJoin
+from ..configparser import ConfigParser
+from ..utils.tools import unique, drop_slash
 from . import env
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -82,10 +81,10 @@ class Linux(VariableInterface):
         if path.exists(inifile):
             with open(inifile) as f:
                 data = f.readlins()
-            short_name_list = filter(
-                None, map(lambda x: (len(x.split("=")) == 2 and
-                                     x.split("=")[0] == "calculate" and
-                                     x.split("=")[1].strip()), data))
+            short_name_list = [x for x 
+                in [len(y.split("=")) == 2 and
+                    y.split("=")[0] == "calculate" and
+                    y.split("=")[1].strip() for y in data] if x]
             if short_name_list:
                 return short_name_list[0]
 
@@ -94,8 +93,7 @@ class Linux(VariableInterface):
         gentoo_file = path.join(systemroot, "etc/gentoo-release")
         if path.exists(gentoo_file):
             return "Gentoo"
-        if all(map(lambda x: path.lexists(path.join(systemroot, x)),
-                   ['bin', 'var', 'lib', 'etc'])):
+        if all([path.lexists(path.join(systemroot, x)) for x in ['bin', 'var', 'lib', 'etc']]):
             return "Linux"
         return None
 
@@ -122,14 +120,13 @@ class Linux(VariableInterface):
         if path.exists(pathname):
             with open(pathname) as f:
                 data = f.readlines()
-            ver_list = filter(
-                None, map(lambda x:
-                          (len(x.split("=")) == 2 and
-                           x.split("=")[0] == "linuxver" and
-                           x.split("=")[1].strip()), data))
-            if ver_list:
+            ver_list = [x for x 
+                in [len(y.split("=")) == 2 and
+                    y.split("=")[0] == "linuxver" and
+                    y.split("=")[1].strip() for y in data] if x]
+            if not ver_list:
                 re_ver = re.compile("^(\d+\.)*\d$", re.S)
-                re_res = filter(re_ver.search, ver_list)
+                re_res = [x for x in ver_list if re_ver.search(x)]
                 if re_res:
                     return re_res[0]
 
@@ -140,8 +137,7 @@ class Linux(VariableInterface):
         if path.exists(gentoo_file):
             gentoo_link = self.Get('cl_make_profile')
             if path.islink(gentoo_link):
-                vers = filter(re_ver.search,
-                              os.readlink(gentoo_link).split('/'))
+                vers = [x for x in os.readlink(gentoo_link).split('/') if re_ver.search(x)]
                 if vers:
                     return vers[-1]
 
@@ -258,13 +254,12 @@ class VariableOsLinuxPkglist(Variable):
                                                           'os_linux_shortname',
                                                           raw=True,
                                                           fallback=''))
-            yield value.encode('utf-8')
+            yield value
 
     def get(self):
         make_profile = self.Get('cl_make_profile')
         if path.exists(make_profile):
-            return list(unique(filter(None,
-                                   self.generate_shortnames(make_profile))))
+            return list(unique((x for x in self.generate_shortnames(make_profile) if x)))
         else:
             return []
 
